"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _ColorGlue_plugins, _ColorGlue_config;
Object.defineProperty(exports, "__esModule", { value: true });
const color_collection_1 = __importDefault(require("./color-collection"));
const plugin_manager_1 = __importDefault(require("./plugin-manager"));
class ColorGlue {
    constructor(plugins, config) {
        _ColorGlue_plugins.set(this, new plugin_manager_1.default());
        _ColorGlue_config.set(this, void 0);
        plugins.forEach(plugin => {
            this.registerPlugin(plugin);
        });
        __classPrivateFieldSet(this, _ColorGlue_config, config, "f");
    }
    appendImporterConfig(config) {
        __classPrivateFieldGet(this, _ColorGlue_config, "f").importers.push(config);
    }
    appendUrlGeneratorConfig(config) {
        __classPrivateFieldGet(this, _ColorGlue_config, "f").urlGenerators.push(config);
    }
    async importColors() {
        let colors = new color_collection_1.default();
        for (const importerPluginConfig of __classPrivateFieldGet(this, _ColorGlue_config, "f").importers) {
            const key = typeof importerPluginConfig === 'string' ? importerPluginConfig : importerPluginConfig.name;
            const config = importerPluginConfig.importConfig;
            const plugin = __classPrivateFieldGet(this, _ColorGlue_plugins, "f").getImporterPlugin(key);
            if (plugin === undefined) {
                console.warn(`Could not find importer plugin with key: ${key}`);
                continue;
            }
            colors = await plugin.import(colors, config);
        }
        return colors;
    }
    async generateUrls(colors) {
        const urls = [];
        for (const urlGenPluginConfig of __classPrivateFieldGet(this, _ColorGlue_config, "f").urlGenerators) {
            const key = typeof urlGenPluginConfig === 'string' ? urlGenPluginConfig : urlGenPluginConfig.name;
            const config = urlGenPluginConfig.urlGeneratorConfig;
            const plugin = __classPrivateFieldGet(this, _ColorGlue_plugins, "f").getUrlGeneratorPlugin(key);
            if (plugin === undefined) {
                console.warn(`Could not find URL generator plugin with key: ${key}`);
                continue;
            }
            urls.push(await plugin.generateUrl(colors, config));
        }
        return urls;
    }
    async run() {
        const colors = await this.importColors();
        const urls = await this.generateUrls(colors);
        return {
            colors,
            urls,
        };
    }
    registerPlugin(plugin) {
        __classPrivateFieldGet(this, _ColorGlue_plugins, "f").registerPlugin(plugin);
    }
    getPluginsInfo() {
        return __classPrivateFieldGet(this, _ColorGlue_plugins, "f").getPluginsInfo();
    }
}
exports.default = ColorGlue;
_ColorGlue_plugins = new WeakMap(), _ColorGlue_config = new WeakMap();
//# sourceMappingURL=color-glue.js.map