/// <reference types="node" />
import { URL } from 'url';
import ColorCollection from '../color-collection';
import ImporterPlugin, { ImportPluginConfig } from '../interfaces/importer';
declare const configKey = "invisionDsm";
export interface DsmImportConfig {
    /**
     * One or more JSON design token URLs.
     *
     * `list`, `lookup` and `list,lookup` export formats are
     * supported.
     */
    url: (string | URL) | (string | URL)[];
}
export interface DsmImportPluginConfig extends ImportPluginConfig<DsmImportConfig> {
    name: typeof configKey;
}
/**
 * Importer plugin for fetching all colours defined in an
 * InVision DSM library.
 */
export default class DsmPlugin implements ImporterPlugin<DsmImportConfig> {
    get configKey(): string;
    get displayName(): string;
    /**
     * Fetches JSON design tokens from DSM and extracts all
     * the colours from them.
     *
     * @param colors  Color collection that all imported colors
     *                will be added to.
     * @param config  Config object listing the URL(s) to fetch
     *                from.
     */
    import(colors: ColorCollection, config: DsmImportConfig): Promise<ColorCollection>;
}
export {};
