"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const https_1 = __importDefault(require("https"));
const configKey = 'invisionDsm';
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isColorCollection(tokenOrCollection) {
    return tokenOrCollection.colors !== undefined && Array.isArray(tokenOrCollection.colors);
}
/**
 * Importer plugin for fetching all colours defined in an
 * InVision DSM library.
 */
class DsmPlugin {
    get configKey() {
        return configKey;
    }
    get displayName() {
        return 'InVision DSM';
    }
    /**
     * Fetches JSON design tokens from DSM and extracts all
     * the colours from them.
     *
     * @param colors  Color collection that all imported colors
     *                will be added to.
     * @param config  Config object listing the URL(s) to fetch
     *                from.
     */
    async import(colors, config) {
        const urls = Array.isArray(config.url) ? config.url : [config.url];
        for (const url of urls) {
            // Fetch the JSON file
            const jsonString = await new Promise((resolve, reject) => {
                https_1.default.get(url, res => {
                    let responseBody = '';
                    res.on('data', chunk => {
                        responseBody += chunk;
                    });
                    res.on('end', () => {
                        resolve(responseBody);
                    });
                }).on('error', reject);
            });
            // Parse the received JSON data
            const designTokenData = JSON.parse(jsonString);
            // Extract list colors:
            if (designTokenData.list !== undefined) {
                designTokenData.list.colors.forEach(colorCategory => {
                    colorCategory.colors.forEach(colorToken => {
                        colors.addColor(colorToken.value, colorToken.name);
                    });
                });
            }
            // Extract lookup colors:
            if (designTokenData.lookup !== undefined) {
                Object.getOwnPropertyNames(designTokenData.lookup.colors).forEach(colorOrCategoryName => {
                    var _a;
                    const colorOrCategory = (_a = designTokenData.lookup) === null || _a === void 0 ? void 0 : _a.colors[colorOrCategoryName];
                    if (isColorCollection(colorOrCategory)) {
                        colorOrCategory.colors.forEach(colorToken => {
                            colors.addColor(colorToken.value, colorToken.name);
                        });
                    }
                    else if (colorOrCategory !== undefined) {
                        colors.addColor(colorOrCategory.value, colorOrCategory.name);
                    }
                });
            }
        }
        return colors;
    }
}
exports.default = DsmPlugin;
//# sourceMappingURL=invision-dsm.js.map